middleware

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 7, 2025 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package middleware contains the middleware to be used by services

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AuthorizationMiddleware

func AuthorizationMiddleware() func(http.Handler) http.Handler

AuthorizationMiddleware creates a middleware that adds a request ID to the context

func RequestIDMiddleware

func RequestIDMiddleware() func(http.Handler) http.Handler

RequestIDMiddleware creates a middleware that adds a request ID to the context

func RequestLoggerMiddleware

func RequestLoggerMiddleware() func(http.Handler) http.Handler

RequestLoggerMiddleware creates a middleware that logs HTTP requests

Types

This section is empty.

Jump to